#ifndef ORB_Task__h_
#define ORB_Task__h_
/**
 * @file ORB_Task.h
 *
 * @author Johnny Willemsen  <jwillemsen@remedy.nl>
 */
#include "tao/ORB.h"
#include "ace/Task.h"

class ORB_Task : public ACE_Task_Base
{
public:
  ORB_Task(CORBA::ORB_ptr orb);

  virtual int svc ();

private:
  CORBA::ORB_var orb_;
};

#endif /* ORB_Task__h_ */
